"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeleteGenerativeUsage = exports.GetGenerativeUsages = exports.GetGenerativeUsage = exports.SaveGenerativeUsage = exports.DeleteGenerativeToken = exports.GetGenerativeToken = exports.SaveGenerativeToken = exports.GenerativeRedis = void 0;
const log4js = require("log4js");
let logger = log4js.getLogger('Redis');
let redisClient;
function GenerativeRedis(app) {
    redisClient = app.get('redisClient');
}
exports.GenerativeRedis = GenerativeRedis;
function SaveGenerativeToken(vcc, token) {
    let hash = 'GenerativeToken';
    return redisClient.hsetAsync(hash, vcc, token)
        .then(_ => {
        return Promise.resolve(true);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::SaveGenerativeToken] getting error:', err, 'with vcc:', vcc);
        return Promise.resolve(false);
    });
}
exports.SaveGenerativeToken = SaveGenerativeToken;
function GetGenerativeToken(vcc) {
    let hash = 'GenerativeToken';
    return redisClient.hgetAsync(hash, vcc)
        .then(result => {
        return Promise.resolve(result);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::GetGenerativeToken] getting err value:', err, 'hash:', hash, 'vcc:', vcc);
        return Promise.resolve(null);
    });
}
exports.GetGenerativeToken = GetGenerativeToken;
function DeleteGenerativeToken(vcc) {
    let hash = 'GenerativeToken';
    return redisClient.hdelAsync(hash, vcc)
        .then((result) => {
        return Promise.resolve(result ? true : false);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::DeleteGenerativeToken] getting error:', err, 'with vcc:', vcc);
        return Promise.resolve(null);
    });
}
exports.DeleteGenerativeToken = DeleteGenerativeToken;
function SaveGenerativeUsage(vcc, evaluationPlanId, interactionId, appId, tokens) {
    let hash = `${vcc}:GenerativeUsage:${evaluationPlanId}`;
    return redisClient.hsetAsync(hash, `${interactionId}:${appId}`, tokens)
        .then(_ => {
        return Promise.resolve(true);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::SaveGenerativeUsage] getting error:', err, 'with vcc:', vcc);
        return Promise.resolve(false);
    });
}
exports.SaveGenerativeUsage = SaveGenerativeUsage;
function GetGenerativeUsage(vcc, evaluationPlanId, interactionId, appId) {
    let hash = `${vcc}:GenerativeUsage:${evaluationPlanId}`;
    return redisClient.hgetAsync(hash, `${interactionId}:${appId}`)
        .then(result => {
        return Promise.resolve(result);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::GetGenerativeUsage] getting err value:', err, 'hash:', hash, 'vcc:', vcc);
        return Promise.resolve(null);
    });
}
exports.GetGenerativeUsage = GetGenerativeUsage;
function GetGenerativeUsages(vcc, evaluationPlanId, interactionId) {
    let hash = `${vcc}:GenerativeUsage:${evaluationPlanId}`;
    let interactionAppIds = [];
    let usages = {};
    return redisClient.hkeysAsync(hash)
        .then(result => {
        if (!result)
            result = [];
        interactionAppIds = result.filter(r => r.includes(`${interactionId}:`));
        return redisClient.hmgetAsync(hash, interactionAppIds);
    })
        .then(result => {
        if (!result)
            result = [];
        interactionAppIds.forEach((iai, i) => {
            let app = iai.replace(`${interactionId}:`, '');
            let usage = Number(result[i]) || 0;
            usages[app] = usage;
        });
        return Promise.resolve(usages);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::GetGenerativeUsages] getting err value:', err, 'hash:', hash, 'vcc:', vcc);
        return Promise.resolve(null);
    });
}
exports.GetGenerativeUsages = GetGenerativeUsages;
function DeleteGenerativeUsage(vcc, evaluationPlanId, interactionId, appId) {
    let hash = `${vcc}:GenerativeUsage:${evaluationPlanId}`;
    return redisClient.hdelAsync(hash, `${interactionId}:${appId}`)
        .then((result) => {
        return Promise.resolve(result ? true : false);
    })
        .catch((err) => {
        logger.error('[GenerativeRedis::DeleteGenerativeUsage] getting error:', err, 'with vcc:', vcc);
        return Promise.resolve(null);
    });
}
exports.DeleteGenerativeUsage = DeleteGenerativeUsage;
