"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerativeAnalysisImplementation = void 0;
const tiktoken_1 = require("tiktoken");
const log4js = require("log4js");
const billing_batch_model_1 = require("../models/billing-batch.model");
const promises_shared_1 = require("../shared/promises.shared");
const redis_service_1 = require("../db/redis.service");
let logger = log4js.getLogger('Task');
const CURRENT_SYSTEM_SERVICE = 'GENERATIVE_ANALYSIS';
const CURRENT_IMPLEMENTATION = 'GenerativeAnalysisImplementation';
class GenerativeAnalysisImplementation {
    constructor() {
        this.errorData = new billing_batch_model_1.BatchError();
    }
    Execute(executionCode, rateRecursive) {
        return promises_shared_1.DummyPromise()
            .then(_ => {
            return Promise.resolve(true);
        });
    }
    GetAppsList() {
        return promises_shared_1.DummyPromise()
            .then(_ => {
            return Promise.resolve([]);
        });
    }
    ;
    SaveUsageOnRedis(vcc, evaluationPlanId, interactionId, appId, tokens) {
        let logLabel = `[${CURRENT_IMPLEMENTATION}::SaveApp] [vcc::evaluationPlan::interactionId::appId => ${vcc}::${evaluationPlanId}::${interactionId}::${appId}]: `;
        logger.info(`${logLabel}Registering +${tokens} tokens`);
        let currentUsage = 0;
        return promises_shared_1.DummyPromise()
            .then(_ => {
            return redis_service_1.Redis.GetGenerativeUsage(vcc, evaluationPlanId, interactionId, appId);
        })
            .then(result => {
            if (result)
                currentUsage = result;
            return redis_service_1.Redis.SaveGenerativeUsage(vcc, evaluationPlanId, interactionId, appId, currentUsage + tokens);
        })
            .catch((error) => {
            let errorMessage = typeof error === 'string' ? error : (error.message || error.description);
            logger.error(`${logLabel} getting error: ${errorMessage}`);
            return Promise.resolve(false);
        });
    }
    CalculateTokens(phrase) {
        let logLabel = `[${CURRENT_IMPLEMENTATION}::CalculateTokens] [phrase => ${phrase}]: `;
        const enc = tiktoken_1.encoding_for_model("gpt-4-turbo-preview");
        const result = enc.encode(phrase);
        console.log(phrase + ':', result);
        logger.info(`${logLabel}Found tokens: ${result.length}`);
        return result.length;
    }
}
exports.GenerativeAnalysisImplementation = GenerativeAnalysisImplementation;
